@@ -31,15 +31,17 @@ def main():
     
     # beefed up %env is handy in shell mode
     import envpersist
+    import ipy_which
+    import ipy_stock_completers
     
     
     ip.ex('import os')
     ip.ex("def up(): os.chdir('..')")
         
-    # Get pysh-like prompt for all profiles. 
+    # Nice prompt
     
-    o.prompt_in1= '\C_LightBlue[\C_LightCyan\Y1\C_LightBlue]\C_Green|\#> '
-    o.prompt_in2= '\C_Green|\C_LightGreen\D\C_Green> '
+    o.prompt_in1= r'\C_LightBlue[\C_LightCyan\Y2\C_LightBlue]\C_Green|\#> '
+    o.prompt_in2= r'\C_Green|\C_LightGreen\D\C_Green> '
     o.prompt_out= '<\#> '
     
     from IPython import Release
@@ -52,12 +54,12 @@ def main():
     
     ip.magic('alias d ls -F --color=auto')
     
-    # Make available all system commands through "rehashing" immediately. 
-    # You can comment these lines out to speed up startup on very slow 
-    # machines, and to conserve a bit of memory. Note that pysh profile does this
-    # automatically
     ip.IP.default_option('cd','-q')
     
+    # If you only rarely want to execute the things you %edit...
+    
+    #ip.IP.default_option('edit','-x')
+    
 
     o.prompts_pad_left="1"
     # Remove all blank lines in between prompts, like a normal shell.
