@@ -215,13 +215,15 @@ class Completer:
             words.append('__class__')
             words.extend(get_class_members(object.__class__))
 
+        # Some libraries (such as traits) may introduce duplicates, we want to
+        # track and clean this up if it happens
+        may_have_dupes = False
+
         # this is the 'dir' function for objects with Enthought's traits
         if hasattr(object, 'trait_names'):
             try:
                 words.extend(object.trait_names())
-                # eliminate possible duplicates, as some traits may also
-                # appear as normal attributes in the dir() call.
-                words = set(words)
+                may_have_dupes = True
             except TypeError:
                 # This will happen if `object` is a class and not an instance.
                 pass
@@ -230,13 +232,17 @@ class Completer:
         if hasattr(object, '_getAttributeNames'):
             try:
                 words.extend(object._getAttributeNames())
-                # Eliminate duplicates.
-                words = set(words)
+                may_have_dupes = True
             except TypeError:
                 # `object` is a class and not an instance.  Ignore
                 # this error.
                 pass
 
+        if may_have_dupes:
+            # eliminate possible duplicates, as some traits may also
+            # appear as normal attributes in the dir() call.
+            words = set(words)
+
         # filter out non-string attributes which may be stuffed by dir() calls
         # and poor coding in third-party modules
         words = [w for w in words
@@ -366,6 +372,26 @@ class IPCompleter(Completer):
         def protect_filename(s):
             return "".join([(ch in protectables and '\\' + ch or ch)
                             for ch in s])
+
+        def single_dir_expand(matches):
+            "Recursively expand match lists containing a single dir."
+            
+            if len(matches) == 1 and os.path.isdir(matches[0]):
+                # Takes care of links to directories also.  Use '/'
+                # explicitly, even under Windows, so that name completions
+                # don't end up escaped.
+                d = matches[0]
+                if d[-1] in ['/','\\']:
+                    d = d[:-1]
+
+                subdirs = os.listdir(d)
+                if subdirs:
+                    matches = [ (d + '/' + p) for p in subdirs]
+                    return single_dir_expand(matches)
+                else:
+                    return matches
+            else:
+                return matches
         
         lbuf = self.lbuf
         open_quotes = 0  # track strings with open quotes
@@ -414,17 +440,9 @@ class IPCompleter(Completer):
             else:
                 matches = [text_prefix + 
                            protect_filename(f) for f in m0]
-        if len(matches) == 1 and os.path.isdir(matches[0]):
-            # Takes care of links to directories also.  Use '/'
-            # explicitly, even under Windows, so that name completions
-            # don't end up escaped.            
-            d = matches[0]
-            if d[-1] in ['/','\\']:
-                d = d[:-1]
-            
-            matches = [ (d + '/' + p) for p in os.listdir(d) ]
-            
-        return matches
+
+        #print 'mm',matches  # dbg
+        return single_dir_expand(matches)
 
     def alias_matches(self, text):
         """Match internal system aliases"""        
@@ -581,12 +599,19 @@ class IPCompleter(Completer):
         return None
         
     
-    
-    def complete(self, text, state):
+    def complete(self, text, state,line_buffer=None):
         """Return the next possible completion for 'text'.
 
         This is called successively with state == 0, 1, 2, ... until it
-        returns None.  The completion should begin with 'text'.  """
+        returns None.  The completion should begin with 'text'.
+
+        :Keywords:
+        - line_buffer: string
+        If not given, the completer attempts to obtain the current line buffer
+        via readline.  This keyword allows clients which are requesting for
+        text completions in non-readline contexts to inform the completer of
+        the entire text.
+        """
 
         #print '\n*** COMPLETE: <%s> (%s)' % (text,state)  # dbg
 
@@ -598,16 +623,20 @@ class IPCompleter(Completer):
 
         # don't apply this on 'dumb' terminals, such as emacs buffers, so we
         # don't interfere with their own tab-completion mechanism.
-        self.full_lbuf = self.get_line_buffer()
-        self.lbuf = self.full_lbuf[:self.readline.get_endidx()]
-        if not (self.dumb_terminal or self.get_line_buffer().strip()):
+        if line_buffer is None:
+            self.full_lbuf = self.get_line_buffer()
+        else:
+            self.full_lbuf = line_buffer
+            
+        if not (self.dumb_terminal or self.full_lbuf.strip()):
             self.readline.insert_text('\t')
             return None
-
         
         magic_escape = self.magic_escape
         magic_prefix = self.magic_prefix
 
+        self.lbuf = self.full_lbuf[:self.readline.get_endidx()]
+
         try:
             if text.startswith(magic_escape):
                 text = text.replace(magic_escape,magic_prefix)
@@ -637,8 +666,8 @@ class IPCompleter(Completer):
             except IndexError:
                 return None
         except:
-            from IPython.ultraTB import AutoFormattedTB; # dbg
-            tb=AutoFormattedTB('Verbose');tb() #dbg
+            #from IPython.ultraTB import AutoFormattedTB; # dbg
+            #tb=AutoFormattedTB('Verbose');tb() #dbg
 
             # If completion fails, don't annoy the user.
             return None
